# -*- mode: cperl; tab-width: 8; indent-tabs-mode: nil; basic-offset: 2 -*-
# vim:ts=8:sw=2:et:sta:sts=2
package Module::Build::ModuleInfo;
$Module::Build::ModuleInfo::VERSION = '0.001';
use strict;
use warnings;

use base 'Module::Metadata';

1;

# ABSTRACT: DEPRECATED

__END__

=pod

=encoding UTF-8

=head1 NAME

Module::Build::ModuleInfo - DEPRECATED

=head1 VERSION

version 0.001

=head1 DESCRIPTION

This module has been extracted into a separate distribution and renamed
L<Module::Metadata>.  This module is kept as a subclass wrapper for
compatibility.

=head1 SEE ALSO

perl(1), L<Module::Build>, L<Module::Metadata>

=head1 AUTHOR

Leon Timmermans <leont@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2013 by Leon Timmermans.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
